@@ -647,28 +647,6 @@ const tI18nPhrase Phrases[] = {
     "", // Dansk
     "", // esky (Czech)
   },
-  { "Use syslog output", // English
-    "Benutze syslog Ausgabe", // Deutsch
-    "", // Slovenski
-    "Registra su syslog", // Italiano
-    "", // Nederlands
-    "", // Portugus
-    "Enregistrer les infos dans syslog", // Franais
-    "", // Norsk
-    "Kirjaa systeemilokiin", // suomi
-    "", // Polski
-    "Usar syslog como registro", // Espaol
-    "", //  (Greek)
-    "", // Svenska
-    "", // Romaneste
-    "", // Magyar
-    "", // Catal
-    "  syslog", //  (Russian)
-    "", // Hrvatski (Croatian)
-    "Kirjuta ssteemilogisse", // Eesti
-    "", // Dansk
-    "", // esky (Czech)
-  },
   { "Audio", // English
     "Audio", // Deutsch
     "Audio", // Slovenski
@@ -2304,7 +2282,7 @@ const tI18nPhrase Phrases[] = {
     "", // Nederlands
     "", // Portugus
     "SkyCrypt", // Franais
-    "", // Norsk   
+    "", // Norsk
     "SkyCrypt", // suomi
     "", // Polski
     "SkyCrypt", // Espaol
@@ -2319,6 +2297,72 @@ const tI18nPhrase Phrases[] = {
     "", // Dansk
     "", // esky (Czech)
   },
+  { "Use SVDRP service", // English
+    "SVDRP Service verwenden", // Deutsch
+    "", // Slovenski
+    "", // Italiano
+    "", // Nederlands
+    "", // Portugus
+    "", // Franais
+    "", // Norsk
+    "Kyt SVDRP-palvelua", // suomi
+    "", // Polski
+    "", // Espaol
+    "", //  (Greek)
+    "", // Svenska
+    "", // Romaneste
+    "", // Magyar
+    "", // Catal
+    "", //  (Russian)
+    "", // Hrvatski (Croatian)
+    "", // Eesti
+    "", // Dansk
+    "", // esky (Czech)
+  },
+  { "SVDRP service IP", // English
+    "SVDRP Service IP", // Deutsch
+    "", // Slovenski
+    "", // Italiano
+    "", // Nederlands
+    "", // Portugus
+    "", // Franais
+    "", // Norsk
+    "SVDRP-palvelun IP-osoite", // suomi
+    "", // Polski
+    "", // Espaol
+    "", //  (Greek)
+    "", // Svenska
+    "", // Romaneste
+    "", // Magyar
+    "", // Catal
+    "", //  (Russian)
+    "", // Hrvatski (Croatian)
+    "", // Eesti
+    "", // Dansk
+    "", // esky (Czech)
+  },
+  { "SVDRP service port", // English
+    "SVDRP Service Port", // Deutsch
+    "", // Slovenski
+    "", // Italiano
+    "", // Nederlands
+    "", // Portugus
+    "", // Franais
+    "", // Norsk
+    "SVDRP-palvelun portti", // suomi
+    "", // Polski
+    "", // Espaol
+    "", //  (Greek)
+    "", // Svenska
+    "", // Romaneste
+    "", // Magyar
+    "", // Catal
+    "", //  (Russian)
+    "", // Hrvatski (Croatian)
+    "", // Eesti
+    "", // Dansk
+    "", // esky (Czech)
+  },
   { NULL }
 };
 
